#!/bin/sh
echo 'name: polyparse
version: 1.9
id: polyparse-1.9-b5f5bd214b1b2a7afc4372c48e61bd4a

license: LGPL
copyright:
maintainer: author
stability:
homepage: http://code.haskell.org/~malcolm/polyparse/
package-url:
synopsis: A variety of alternative parser combinator libraries.
description: A variety of alternative parser combinator libraries, including
             the original HuttonMeijer set.  The Poly sets have features like
             good error reporting, arbitrary token type, running state, lazy
             parsing, and so on.  Finally, Text.Parse is a proposed
             replacement for the standard Read class, for better
             deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
pkgpath: textproc/hs-polyparse
exposed: True
exposed-modules: Text.ParserCombinators.Poly.ByteString
                 Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
                 Text.ParserCombinators.Poly.Text
                 Text.ParserCombinators.Poly.StateText
                 Text.ParserCombinators.HuttonMeijer
                 Text.ParserCombinators.HuttonMeijerWallace
                 Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
                 Text.ParserCombinators.Poly.Result
                 Text.ParserCombinators.Poly.Parser
                 Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
                 Text.ParserCombinators.Poly.StateParser
                 Text.ParserCombinators.Poly.State
                 Text.ParserCombinators.Poly.StateLazy
                 Text.ParserCombinators.Poly.Lex Text.Parse
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/polyparse-1.9
library-dirs: /usr/local/lib/ghc/polyparse-1.9
hs-libraries: HSpolyparse-1.9
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-polyparse-1.9/html/polyparse.haddock
haddock-html: /usr/local/share/doc/hs-polyparse-1.9/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
